# Custom Transformer

You can use the custom transformer element to create more complex transformers. Edit the transformer's description to specify what kind of transformer you want.

An example description is: `1:1`. That is a simple transformer with an equal number of turns in the primary and secondary. The inductance of each winding is equal to the "Base Inductance".

`1:10` gives you a step-up transformer. The secondary has 10 times as many turns as the primary (so it has 100 times the base inductance).

`1,2:3` gives you a transformer with two primary windings. The second primary winding has twice as many turns as the first. The secondary winding has 3 times as many. The only difference between primary and secondary windings is how they're displayed on the screen.

`1:.5+.5` gives you a tapped transformer.

`1:1+2` gives you a tapped transformer where the first part of the secondary has as many turns as the primary, and the second part has twice as many.

`1,-1:1` gives you a transformer with two primary windings, where the bottom winding has its polarity swapped.

So, the description is a list of windings separated by commas, with `:` to separate primary and secondary, and `+` to separate parts of a tapped coil.